@@ -103,6 +103,9 @@ class Forum(models.Model):
     def update_counters(self):
         self.post_count = Post.objects.filter(topic__forum=self).count()
         self.topic_count = Topic.objects.filter(forum=self).count()
+        last_post = self.get_last_post()
+        if last_post:
+            self.updated = self.last_post.updated or self.last_post.created
         self.save()
 
     def get_absolute_url(self):
@@ -132,7 +135,12 @@ class Topic(models.Model):
     views = models.IntegerField(_('Views count'), blank=True, default=0)
     sticky = models.BooleanField(_('Sticky'), blank=True, default=False)
     closed = models.BooleanField(_('Closed'), blank=True, default=False)
-    subscribers = models.ManyToManyField(User, related_name='subscriptions', verbose_name=_('Subscribers'), blank=True)
+    subscribers = models.ManyToManyField(
+        User,
+        related_name='subscriptions',
+        verbose_name=_('Subscribers'),
+        blank=True
+    )
     post_count = models.IntegerField(_('Post count'), blank=True, default=0)
     readed_by = models.ManyToManyField(User, through='TopicReadTracker', related_name='readed_topics')
 
@@ -167,6 +175,7 @@ class Topic(models.Model):
 
     def update_counters(self):
         self.post_count = self.posts.count()
+        self.updated = self.last_post.updated or self.last_post.created
         self.save()
 
 
@@ -224,9 +233,10 @@ class Post(RenderableItem):
 
         if new:
             self.topic.updated = now
-            self.topic.update_counters()
             self.topic.forum.updated = now
-            self.topic.forum.update_counters()
+            
+        self.topic.update_counters()
+        self.topic.forum.update_counters()
 
     def get_absolute_url(self):
         return reverse('pybb:post', args=[self.id])
