@@ -1,5 +1,6 @@
 #!/usr/bin/env python
 # vim:fileencoding=utf-8
+from time import sleep
 
 __author__ = 'zeus'
 
@@ -16,7 +17,7 @@ try:
 except:
     raise Exception('PyBB requires lxml for self testing')
 
-class BasicFeaturesTest(TestCase):
+class FeaturesTest(TestCase):
     def setUp(self):
         self.user = User.objects.create_user('zeus', 'zeus@localhost', 'zeus')
         self.category = Category(name='foo')
@@ -27,6 +28,7 @@ class BasicFeaturesTest(TestCase):
         self.topic.save()
         self.post = Post(topic=self.topic, user=self.user, body='bbcode [b]test[b]', markup='bbcode')
         self.post.save()
+        mail.outbox = []
 
     def test_base(self):
         client = Client()
@@ -106,6 +108,16 @@ class BasicFeaturesTest(TestCase):
         topic.delete()
         Forum.objects.get(id=self.forum.id)
 
+
+    def test_forum_updated(self):
+        sleep(1)
+        topic = Topic(name='xtopic', forum=self.forum, user=self.user)
+        topic.save()
+        post = Post(topic=topic, user=self.user, body='one', markup='bbcode')
+        post.save()
+        post = Post.objects.get(id=post.id)
+        self.assertTrue(self.forum.updated==post.created)
+
     def test_read_tracking(self):
         topic = Topic(name='xtopic', forum=self.forum, user=self.user)
         topic.save()
@@ -144,6 +156,11 @@ class BasicFeaturesTest(TestCase):
         client.get(reverse('pybb:mark_all_as_read'))
         tree = html.fromstring(client.get(reverse('pybb:index')).content)
         self.assertFalse(tree.xpath('//a[@href="%s"]/parent::td[contains(@class,"unread")]' % topic.forum.get_absolute_url()))
+        # Empty forum - readed
+        f = Forum(name='empty', category=self.category)
+        f.save()
+        tree = html.fromstring(client.get(reverse('pybb:index')).content)
+        self.assertFalse(tree.xpath('//a[@href="%s"]/parent::td[contains(@class,"unread")]' % f.get_absolute_url()))
 
 
     def test_hidden(self):
@@ -323,9 +340,26 @@ class BasicFeaturesTest(TestCase):
         self.assertTrue(user in list(self.topic.subscribers.all()))
         new_post = Post(topic=self.topic, user=self.user, body='test subscribtion юникод', markup='bbcode')
         new_post.save()
-        self.assertEquals(len(mail.outbox), 1)
+        self.assertTrue([msg for msg in mail.outbox if new_post.get_absolute_url() in msg.body])
         response = client.get(reverse('pybb:delete_subscription', args=[self.topic.id]), follow=True)
         self.assertTrue(response.status_code==200)
         self.assertTrue(user not in list(self.topic.subscribers.all()))
 
+    def test_topic_updated(self):
+        topic = Topic(name='etopic', forum=self.forum, user=self.user)
+        topic.save()
+        sleep(1)
+        post = Post(topic=topic, user=self.user, body='bbcode [b]test[b]', markup='bbcode')
+        post.save()
+        client = Client()
+        response = client.get(self.forum.get_absolute_url())
+        self.assertTrue(response.context['topic_list'][0]==topic)
+        sleep(1)
+        post = Post(topic=self.topic, user=self.user, body='bbcode [b]test[b]', markup='bbcode')
+        post.save()
+        client = Client()
+        response = client.get(self.forum.get_absolute_url())
+        self.assertTrue(response.context['topic_list'][0]==self.topic)
+
+
         
